@@ -1,3 +1,11 @@
+"""
+CPG in polar coordinates based on:
+Pattern generators with sensory feedback for the control of quadruped
+authors: L. Righetti, A. Ijspeert
+https://ieeexplore.ieee.org/stamp/stamp.jsp?arnumber=4543306
+Original author: Guillaume Bellegarda
+"""
+
 from functools import partial
 import numpy as np
 
